<?php 
/**
 * About us
 * about image section
 *
 * This is the template for the content of about_image section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_about_image_section' ) ) :
    /**
    * Add about_image section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_about_image_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if about_image is enabled
        $enable_about_image = $options['about_image_enable'];

        if ( true !== $enable_about_image ) {
            return false;
        }

        // Render about_image section now.
        corporate_education_pro_render_about_image_section();
    }
endif;
add_action( 'corporate_education_pro_about_template_image_content', 'corporate_education_pro_add_about_image_section', 10 );

if ( ! function_exists( 'corporate_education_pro_render_about_image_section' ) ) :
    /**
    * Start about_image section
    *
    * @return string about_image content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_about_image_section() {
        $options = corporate_education_pro_get_theme_options();

        for( $i = 1; $i <= 3; $i++ ) {
            if ( ! empty( $options['about_image_' . $i] ) ) {
                $content_details[$i]['img_array'] = $options['about_image_' . $i];
            }
        }

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div class="featured-images-list col-3">
            <?php foreach ( $content_details as $content_detail ) : ?>
                <div class="hentry">
                    <div class="white-shape top"></div>
                    <div class="white-shape top right"></div>
                    <div class="white-shape bottom"></div>
                    <div class="white-shape bottom left"></div>

                    <img src="<?php echo esc_url( $content_detail['img_array'] ); ?>" alt="<?php esc_html_e( 'About Us', 'corporate-education-pro' ) ?>">
                </div><!-- .hentry-->
            <?php endforeach; ?>
        </div><!-- featured-images-list -->
    <?php }
endif;

/**
 * About us
 * message section
 *
 * This is the template for the content of about_message section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_about_message_section' ) ) :
    /**
    * Add about_message section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_about_message_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if about_message is enabled
        $enable_about_message = $options['message_enable'];

        if ( true !== $enable_about_message ) {
            return false;
        }

        // Get about_message section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_about_message_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render about_message section now.
        corporate_education_pro_render_about_message_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_about_template_content', 'corporate_education_pro_add_about_message_section', 10 );


if ( ! function_exists( 'corporate_education_pro_get_about_message_section_details' ) ) :
    /**
    * about_message section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input about_message section details.
    */
    function corporate_education_pro_get_about_message_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // about_message type
        $about_message_content_type  = $options['message_content_type'];

        $content = array();
        switch ( $about_message_content_type ) {

            case 'post':
                $post_id = '';
                
                if ( ! empty( $options['message_content_post'] ) )
                    $post_id = $options['message_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }

                $content[0]['title']        = get_the_title( $post_id );
                $content[0]['url']          = get_the_permalink( $post_id );
                $content[0]['sub_title']    = ! empty( $options['message_sub_title'] ) ? $options['message_sub_title'] : '';
                $content[0]['excerpt']      = get_post_field( 'post_content', $post_id ); 
                
          	break;

            case 'page':
                $post_id = '';
                
                if ( ! empty( $options['message_content_page'] ) )
                    $post_id = $options['message_content_page'];

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }

                $content[0]['title']        = get_the_title( $post_id );
                $content[0]['url']          = get_the_permalink( $post_id );
                $content[0]['sub_title']    = ! empty( $options['message_sub_title'] ) ? $options['message_sub_title'] : '';
                $content[0]['excerpt']      = get_post_field( 'post_content', $post_id ); 
                
            break;

            case 'custom':
                $content[0]['title']        = ! empty( $options['message_title'] ) ? $options['message_title'] : '';
                $content[0]['url']          = ! empty( $options['message_link'] ) ? $options['message_link'] : '';
                $content[0]['sub_title']    = ! empty( $options['message_sub_title'] ) ? $options['message_sub_title'] : '';
                $content[0]['excerpt']      = ! empty( $options['message_description'] ) ? $options['message_description'] : '';
                
            break;


        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about_message section content details.
add_filter( 'corporate_education_pro_filter_about_message_section_details', 'corporate_education_pro_get_about_message_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_about_message_section' ) ) :
    /**
    * Start about_message section
    *
    * @return string about_message content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_about_message_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
    
        if ( empty( $content_details ) ) {
            return;
        }

        foreach ( $content_details as $content_detail ) : ?>
            <section id="principals-message" class="page-section">
                <div class="blue-shape top move-up left"></div>
                <div class="blue-shape bottom move-down right"></div>

                <div class="wrapper">
                    <div class="entry-content">
                        <blockquote><?php echo esc_html( $content_detail['excerpt'] ); ?></blockquote>

                        <h5><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                        <span><?php echo esc_html( $content_detail['sub_title'] ); ?></span>
                    </div><!-- .entry-content -->
                </div><!-- .wrapper -->
            </section><!-- #principals-message -->
        <?php endforeach; 
    }
endif;


/**
 * About us
 * features section
 *
 * This is the template for the content of about_features section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_about_features_section' ) ) :
    /**
    * Add about_features section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_about_features_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if about_features is enabled
        $enable_about_features = $options['features_enable'];

        if ( true !== $enable_about_features ) {
            return false;
        }

        // Get about_features section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_about_features_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render about_features section now.
        corporate_education_pro_render_about_features_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_about_template_content', 'corporate_education_pro_add_about_features_section', 20 );


if ( ! function_exists( 'corporate_education_pro_get_about_features_section_details' ) ) :
    /**
    * about_features section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input about_features section details.
    */
    function corporate_education_pro_get_about_features_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // about_features type
        $about_features_content_type  = $options['features_content_type'];

        $content = array();
        switch ( $about_features_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['features_content_post'] ) )
                    $ids = ( array ) $options['features_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );  
                
            break;

            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'features_content_page_'.$i ] ) ) {
                        $id = $options[ 'features_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );
            break;

        }

        $posts = get_posts( $args );
        if ( ! empty( $posts ) ) :
            $i = 1;
            foreach ( $posts as $post ) :
                $post_id = $post->ID;
                $content[$i]['id']       = $post_id;
                $content[$i]['title']    = get_the_title( $post_id );
                $content[$i]['url']      = get_the_permalink( $post_id );
                $content[$i]['excerpt']  = corporate_education_pro_trim_content( 20, $post );
                $i++;
            endforeach;
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about_features section content details.
add_filter( 'corporate_education_pro_filter_about_features_section_details', 'corporate_education_pro_get_about_features_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_about_features_section' ) ) :
    /**
    * Start about_features section
    *
    * @return string about_features content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_about_features_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $title = ! empty( $options['features_title'] ) ? $options['features_title'] : '';
        $description = ! empty( $options['features_description'] ) ? $options['features_description'] : '';
    
        if ( empty( $content_details ) ) {
            return;
        }

        $i = 1;
        ?>
            <section id="our-services" class="page-section">
                <div class="white-shape top move-up left"></div>

                <div class="wrapper">
                    <div class="entry-container col-3">
                        <div class="hentry">
                            <?php foreach ( $content_details as $content_detail ) :  ?>
                                <div class="service">
                                    <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ) ?></a></h5>
                                    <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                </div><!-- .service -->
                            <?php if ( $i == 2 ) : ?>      
                                </div><!-- .hentry -->
                                <?php if ( ! empty( $title ) || ! empty( $description ) ) : ?>
                                    <div class="hentry">
                                        <div class="hexagon">
                                            <div class="services-content-details">
                                                <?php if ( ! empty( $title ) ) : ?>
                                                    <header class="entry-header align-center">
                                                        <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                                                    </header>
                                                <?php endif; ?>

                                                <div class="entry-content">
                                                    <p><?php echo esc_html( strip_tags( htmlspecialchars_decode( $description ) ) ); ?></p>
                                                </div><!-- .entry-content -->
                                            </div><!-- .services-content-details -->
                                        </div><!-- .hexagon -->
                                    </div><!-- .hentry -->
                                <?php endif; ?>
                                <div class="hentry">
                            <?php endif; ?>
                        <?php $i++;
                        endforeach; ?>
                    </div><!-- .hentry -->
                </div><!-- .entry-container -->
            </div><!-- .wrapper -->
        </section><!-- #our-services -->
    <?php }
endif;


/**
 * About us
 * Team section
 *
 * This is the template for the content of about_team section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_about_team_section' ) ) :
    /**
    * Add about_team section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_about_team_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if about_team is enabled
        $enable_about_team = $options['about_team_enable'];

        if ( true !== $enable_about_team ) {
            return false;
        }

        // Get about_team section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_about_team_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render about_team section now.
        corporate_education_pro_render_about_team_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_about_template_content', 'corporate_education_pro_add_about_team_section', 30 );


if ( ! function_exists( 'corporate_education_pro_get_about_team_section_details' ) ) :
    /**
    * about_team section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input about_team section details.
    */
    function corporate_education_pro_get_about_team_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // about_team type
        $about_team_content_type  = $options['about_team_content_type'];

        $content = array();
        switch ( $about_team_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['about_team_content_post'] ) )
                    $ids = ( array ) $options['about_team_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 5,
                );  
                
            break;

            case 'team':
                $ids = array();
                
                if ( ! empty( $options['about_team_content_team'] ) )
                    $ids = ( array ) $options['about_team_content_team'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-team',
                    'post__in'       => $ids,
                    'posts_per_page' => 5,
                );  
                
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['about_team_content_category'] ) ) {
                    $cat_id = $options['about_team_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => 5,
                );
            break;

            case 'team-category':
                $cat_id = '';
                if ( ! empty( $options['about_team_content_team_category'] ) ) {
                    $cat_id = $options['about_team_content_team_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-team',
                    'posts_per_page'    => 5,
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-team-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
            break;

        }

        $posts = get_posts( $args );
        if ( ! empty( $posts ) ) :
            $i = 1;
            foreach ( $posts as $post ) :
                $post_id = $post->ID;
                $img_array = array();
                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'corporate-education-pro-medium' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                    $img_array[1] =  500;
                    $img_array[2] =  500;
                }
                if ( isset( $img_array ) ) {
                    $content[$i]['img_array'] = $img_array;
                }
                $content[$i]['id']       = $post_id;
                $content[$i]['title']    = get_the_title( $post_id );
                $content[$i]['url']      = get_the_permalink( $post_id );
                $i++;
            endforeach;
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about_team section content details.
add_filter( 'corporate_education_pro_filter_about_team_section_details', 'corporate_education_pro_get_about_team_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_about_team_section' ) ) :
    /**
    * Start about_team section
    *
    * @return string about_team content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_about_team_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $about_team_content_type  = $options['about_team_content_type'];
        $title = ! empty( $options['about_team_title'] ) ? $options['about_team_title'] : '';
        $sub_title = ! empty( $options['about_team_sub_title'] ) ? $options['about_team_sub_title'] : '';
        $description = ! empty( $options['about_team_description'] ) ? $options['about_team_description'] : '';
        $category_link  = '';
        $cat_name       = '';
        if ( $about_team_content_type == 'category' ) {
            $category_link  = get_category_link( $options['about_team_content_category'] );
            $cat_name       = get_the_category_by_ID( $options['about_team_content_category'] );
        } elseif ( $about_team_content_type == 'team-category' ) {
            $category_link  = get_term_link( $options['about_team_content_team_category' ], 'tp-team-category' );
            $term           = get_term_by('id', $options['about_team_content_team_category' ] , 'tp-team-category' );
            $cat_name       = $term->name;
        }
    
        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="professional-teachers" class="page-section">
            <div class="gray-shape top move-up left"></div>
            <div class="white-shape top right"></div>
            <div class="gray-shape bottom right move-down"></div>
            
            <div class="wrapper">
                <?php if ( ! empty( $title ) || ! empty( $sut_title ) ) : ?>
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                        <?php endif;
                        if ( ! empty( $sub_title ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                        <?php endif; ?>
                    </header>
                <?php endif; ?>

                <div class="entry-container">
                    <?php if ( ! empty( $description ) ) : ?>
                        <div class="entry-content">
                            <p><?php echo wp_kses_post( $description ); ?></p>
                        </div><!-- .entry-content -->
                    <?php endif; ?>

                    <div class="staff-members-wrapper col-5 clear">
                        <?php foreach ( $content_details as $content_detail ) : ?>
                            <div class="hentry">
                                <div class="staff-detail-wrapper">
                                    <figure class="featured-image">
                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content_detail['title'] ); ?>"></a>
                                    </figure>
                                    <div class="staff-details">
                                        <h5 class="staff-name"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                        <?php if ( has_action( 'tp_team_designation_action' ) && in_array( $about_team_content_type, array( 'team', 'team-category' ) ) ) : 
                                            do_action( 'tp_team_designation_action', $content_detail['id'] );
                                        endif; ?>
                                    </div><!-- .staff-details -->
                                </div><!-- .staff-detail-wrapper -->
                            </div><!-- .hentry -->
                        <?php endforeach; ?>
                    </div><!-- .staff-members-wrapper -->

                    <?php if ( ! empty( $category_link ) ) : ?>
                        <div class="view-more align-center">
                            <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-blue-transparent"><?php printf( '%s ' . esc_html( $cat_name ), esc_html__( 'View all', 'corporate-education-pro' ) ); ?></a>
                        </div>
                    <?php endif; ?>

                </div><!-- .entry-container -->
            </div><!-- .wrapper -->
        </section><!-- #professional-teachers -->
    <?php }
endif;
