<?php
/**
 * Theme Palace Theme Customizer.
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function corporate_education_pro_customize_register( $wp_customize ) {
	$options = corporate_education_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	// Add panel for section options
	$wp_customize->add_panel( 'corporate_education_pro_sections_panel' , array(
	    'title'      => esc_html__( 'Homepage Sections','corporate-education-pro' ),
	    'description'=> esc_html__( 'Homepage Section Options', 'corporate-education-pro' ),
	    'priority'   => 150,
	) );
	
	// headline
	require get_template_directory() . '/inc/customizer/sections/headline.php';

	// slider
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// about
	require get_template_directory() . '/inc/customizer/sections/about.php';

	// service
	require get_template_directory() . '/inc/customizer/sections/service.php';

	// courses
	require get_template_directory() . '/inc/customizer/sections/courses.php';

	// call to action
	require get_template_directory() . '/inc/customizer/sections/call-to-action.php';

	// latest news
	require get_template_directory() . '/inc/customizer/sections/latest-news.php';

	// team
	require get_template_directory() . '/inc/customizer/sections/team.php';

	// counter
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	// testimonial
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	// gallery
	require get_template_directory() . '/inc/customizer/sections/gallery.php';

	// subscribe
	require get_template_directory() . '/inc/customizer/sections/subscribe.php';

	// social
	require get_template_directory() . '/inc/customizer/sections/social.php';

	// Add panel for common theme options
	$wp_customize->add_panel( 'corporate_education_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','corporate-education-pro' ),
	    'description'=> esc_html__( 'Theme Palace Theme Options', 'corporate-education-pro' ),
	    'priority'   => 150,
	) );

	// theme color
	require get_template_directory() . '/inc/customizer/theme-options/theme-color.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load blog
	require get_template_directory() . '/inc/customizer/theme-options/blog.php';

	// load single
	require get_template_directory() . '/inc/customizer/theme-options/single.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load excerpt option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load breadcrumb option
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	/*Custom Templates*/
	
	// About us template
	require get_template_directory() . '/inc/customizer/custom-template/about-template.php';
	
	// Abroad Study
	require get_template_directory() . '/inc/customizer/custom-template/study-abroad.php';

	// Service template
	require get_template_directory() . '/inc/customizer/custom-template/service-template.php';

	// Contact us template
	require get_template_directory() . '/inc/customizer/custom-template/contact-template.php';

	
}
add_action( 'customize_register', 'corporate_education_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function corporate_education_pro_customize_preview_js() {
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'corporate_education_pro_customizer', get_template_directory_uri() . '/assets/js/customizer' . $min . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'corporate_education_pro_customize_preview_js' );


if ( !function_exists( 'corporate_education_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Corporate Education Pro 1.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function corporate_education_pro_reset_options() {
		$options = corporate_education_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'corporate_education_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'corporate_education_pro_reset_options' );

if ( !function_exists( 'corporate_education_pro_customize_scripts' ) ) :
	/**
	 * Custom scripts and styles on customize.php
	 *
	 * @since Corporate Education 0.1
	 */
	function corporate_education_pro_customize_scripts() {
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_enqueue_script( 'corporate_education_pro_custom_customizer', get_template_directory_uri() . '/assets/js/custom-customizer' . $min . '.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '', true );

		$corporate_education_pro_data = array(
			'reset_message'	=> esc_html__( 'Refresh the customizer page after saving to view reset effects', 'corporate-education-pro' )
		);

		// Send list of color variables as object to custom customizer js
		wp_localize_script( 'corporate_education_pro_custom_customizer', 'corporate_education_pro_data', $corporate_education_pro_data );
	}
endif;
add_action( 'customize_controls_enqueue_scripts', 'corporate_education_pro_customize_scripts');
