<?php
/**
 * Call to action Section options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$wp_customize->add_section( 'corporate_education_pro_call_to_action', array(
	'title'             => esc_html__( 'Call to Action','corporate-education-pro' ),
	'description'       => esc_html__( 'Call to Action Section Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_sections_panel',
) );

// call_to_action Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['call_to_action_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[call_to_action_enable]', array(
	'label'            	=> esc_html__( 'Enable Call to Action Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_call_to_action',
	'type'             	=> 'checkbox',
) );

// call_to_action content setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_type]', array(
	'sanitize_callback'   => 'corporate_education_pro_sanitize_select',
	'default'             => $options['call_to_action_type'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[call_to_action_type]', array(
	'active_callback'	  => 'corporate_education_pro_is_call_to_action_enable',
	'label'               => esc_html__( 'Content Type', 'corporate-education-pro' ),
	'section'             => 'corporate_education_pro_call_to_action',
	'type'                => 'select',
	'choices'			  => corporate_education_pro_call_to_action(),
) );

// call_to_action Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[call_to_action_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_is_call_to_action_content_post',
	'label'             => esc_html__( 'Input Post Id', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_call_to_action',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_content_page]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_page'
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[call_to_action_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_call_to_action',
	'active_callback' 	=> 'corporate_education_pro_is_call_to_action_content_page',
	'type'				=> 'dropdown-pages'
) );

// call_to_action Section background setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_image]', array(
	'default'           => $options['call_to_action_image'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'corporate_education_pro_theme_options[call_to_action_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'corporate-education-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corporate-education-pro' ), 1500, 1000 ),
		'section'     		=> 'corporate_education_pro_call_to_action',
		'active_callback'	=> 'corporate_education_pro_is_call_to_action_content_custom',
) ) );

// call_to_action Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['call_to_action_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[call_to_action_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_call_to_action',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_call_to_action_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[call_to_action_title]', array(
		'selector'            => '#promotion .wrapper .entry-header h2.entry-title',
		'settings'            => 'corporate_education_pro_theme_options[call_to_action_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_call_to_action_title',
    ) );
}

// call_to_action Section subtitle setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['call_to_action_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[call_to_action_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_call_to_action',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_call_to_action_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[call_to_action_sub_title]', array(
		'selector'            => '#promotion .wrapper .entry-header p.entry-title-desc',
		'settings'            => 'corporate_education_pro_theme_options[call_to_action_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_call_to_action_sub_title',
    ) );
}

for ( $i = 1; $i <= 2; $i++ ) {
	// service post hr setting and control
	$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Corporate_Education_Pro_Customize_Horizontal_Line( $wp_customize, 'corporate_education_pro_theme_options[call_to_action_hr_' . $i . ']',
		array(
			'section'         => 'corporate_education_pro_call_to_action',
			'active_callback' => 'corporate_education_pro_is_call_to_action_content_custom',
			'type'			  => 'hr'
	) ) );

	// call_to_action Section button label setting and control.
	$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_btn_label_' . $i . ']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'default'          	=> $options['call_to_action_btn_label_' . $i],
	) );

	$wp_customize->add_control( 'corporate_education_pro_theme_options[call_to_action_btn_label_' . $i . ']', array(
		'label'            	=> sprintf( esc_html__( 'Button Label %d', 'corporate-education-pro' ), $i ),
		'section'          	=> 'corporate_education_pro_call_to_action',
		'type'             	=> 'text',
		'active_callback'	=> 'corporate_education_pro_is_call_to_action_content_custom',
	) );

	// call_to_action Section button url setting and control.
	$wp_customize->add_setting( 'corporate_education_pro_theme_options[call_to_action_btn_url_' . $i . ']', array(
		'sanitize_callback'	=> 'esc_url_raw',
		'default'          	=> $options['call_to_action_btn_url_' . $i],
	) );

	$wp_customize->add_control( 'corporate_education_pro_theme_options[call_to_action_btn_url_' . $i . ']', array(
		'label'            	=> sprintf( esc_html__( 'Button URL %d', 'corporate-education-pro' ), $i ),
		'section'          	=> 'corporate_education_pro_call_to_action',
		'type'             	=> 'url',
		'active_callback'	=> 'corporate_education_pro_is_call_to_action_content_custom',
	) );
}