<?php 
/**
 * Gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_gallery_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if gallery is enabled
        $enable_gallery = apply_filters( 'corporate_education_pro_section_status', true, 'gallery_enable' );

        if ( true !== $enable_gallery ) {
            return false;
        }

        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_gallery_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render gallery section now.
        corporate_education_pro_render_gallery_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_gallery_section', 90 );


if ( ! function_exists( 'corporate_education_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input gallery section details.
    */
    function corporate_education_pro_get_gallery_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // gallery type
        $gallery_content_type  = $options['gallery_content_type'];
        $no_of_gallery = ! empty( $options['no_of_gallery'] ) ? $options['no_of_gallery'] : 4;

        $content = array();
        switch ( $gallery_content_type ) {
          	case 'demo':
                for ( $i = 1; $i <= 6; $i++ ) :
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/gallery-0' . $i . '.jpg';
                    $content[$i]['img_array_lg'][0] = get_template_directory_uri() . '/assets/uploads/gallery-0' . $i . '.jpg';
                    $content[$i]['title']    = esc_html__( 'WorkShop', 'corporate-education-pro' );
                    $content[$i]['url']      = '#';
                endfor;
            break;        

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['gallery_content_post'] ) )
                    $ids = ( array ) $options['gallery_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  
                
          	break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['gallery_content_category'] ) ) {
                    $cat_id = $options['gallery_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => 6,
                );
            break;
            
        }

        if ( 'demo' != $gallery_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    $img_array_lg = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        if ( $i <= 2 ) :
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'medium_large' );
                            $img_array_lg = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                        else :
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'corporate-education-pro-medium' );
                            $img_array_lg = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                        endif;
                    } else {
                        $img_array[0] = get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                        $img_array_lg[0] = '';
                    }
                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                        $content[$i]['img_array_lg'] = $img_array_lg;
                    }

                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'corporate_education_pro_filter_gallery_section_details', 'corporate_education_pro_get_gallery_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_gallery_section' ) ) :
    /**
    * Start gallery section
    *
    * @return string gallery content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_gallery_section( $content_details ) {
        $options    = corporate_education_pro_get_theme_options();
        $title      = ! empty( $options['gallery_title'] ) ? $options['gallery_title'] : '';
        $sub_title  = ! empty( $options['gallery_sub_title'] ) ? $options['gallery_sub_title'] : '';
        $btn_label  = ! empty( $options['gallery_btn_label'] ) ? $options['gallery_btn_label'] : '';
        $btn_link   = ! empty( $options['gallery_btn_link'] ) ? $options['gallery_btn_link'] : '#';

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="photo-gallery" class="page-section">
            <div class="white-shape top move-up left"></div>
            <div class="white-shape bottom full-width"></div>
            <div class="white-shape bottom left"></div>

            <div class="white-shape bottom move-down right"></div>

            <div class="wrapper">
                <header class="entry-header align-center">
                    <?php if ( ! empty( $title ) ) : ?>
                        <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                    <?php endif; 
                    if ( ! empty( $sub_title ) ) : ?>
                        <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                    <?php endif; ?>
                </header>

                <div class="entry-content">
                    <div class="grid gallery-popup">
                        <?php foreach ( $content_details as $content_detail ) : ?>
                            <div class="grid-item">
                                <figure class="featured-image" style="background-image: url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>');">
                                    <div class="gallery-hover">
                                      <span class="gallery-item-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></span>
                                      <span>
                                          <a href="<?php echo esc_url( $content_detail['img_array_lg'][0] ); ?>" class="popup"><i class="fa fa-camera"></i></a>
                                          <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><i class="fa fa-link"></i></a>
                                      </span>
                                    </div><!-- .gallery-hover -->
                                </figure>
                            </div><!-- .grid-item -->
                        <?php endforeach; ?>
                    </div><!-- .grid -->
                </div><!-- .entry-content -->

                <?php if ( ! empty( $btn_label ) ) : ?>
                    <div class="view-more align-center">
                        <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-blue-transparent"><?php echo esc_html( $btn_label ); ?></a>
                    </div><!-- .view-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </section><!-- #photo-gallery -->
    <?php }
endif;
