<?php
/**
 * Template part for displaying course posts.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$options = corporate_education_pro_get_theme_options();
?>

<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>

	<div class="entry-content no-margin-top wow fadeInUp" data-wow-delay="0.1s" data-wow-duration="0.3s">
		<div class="entry-meta">
			<?php 
			$tp_course_professor = get_post_meta( get_the_id(), 'tp_course_professor_value', true );
			$tp_course_professor = ! empty( $tp_course_professor ) ? $tp_course_professor : '';
			if ( ! empty( $tp_course_professor ) ) :
				$args = array(
					'post_type'	=> 'tp-team',
					'p'			=> $tp_course_professor,
					);
				$posts = get_posts( $args );
				if( ! empty( $posts ) ) :
					foreach ( $posts as $post ) :
						$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'thumbnail' );
				?>
						<div class="pull-left">
							<?php if ( has_post_thumbnail( $post->ID ) ) : ?>
								<div class="image">
									<a href="<?php the_permalink( $post->ID ); ?>">
										<img src="<?php echo esc_url( $image_url[0] ); ?>" alt="<?php echo esc_attr( get_the_title( $post->ID ) ); ?>" >
									</a>
								</div>
							<?php endif; ?>
							<div class="user">
								<small><?php esc_html_e( 'Professor', 'corporate-education-pro' ); ?></small>
	                      		<small><a href="<?php the_permalink( $post->ID ); ?>" class="name"><?php echo esc_html( get_the_title( $post->ID ) ); ?></a></small>
							</div>
						</div>
					<?php endforeach;
				endif; 
				wp_reset_postdata();
			endif;
			?>
			<div class="pull-left categories">
				<small><?php esc_html_e( 'Categories', 'corporate-education-pro' ); ?></small>
				<small>
					<?php 
					if ( function_exists( 'tp_education_get_terms' ) ) :
						tp_education_get_terms( 'tp-course-category', get_the_id() ); 
					endif; 
					?>
				</small>
			</div>

			<div class="pull-left categories">
				<small><?php esc_html_e( 'Likes', 'corporate-education-pro' ); ?></small>
				<small>
					<?php 
					if ( function_exists( 'tp_education_like_button' ) ) :
						echo tp_education_like_button(); 
					endif;
					?>
				</small>
			</div>

			<div class="pull-left reviews">
				<small><?php esc_html_e( 'Reviews', 'corporate-education-pro' ); ?></small>
				<small class="reviews-number">( <?php echo absint( get_comments_number() ) . ' ' . esc_html__( 'Reviews', 'corporate-education-pro' ); ?> )</small>
			</div>

		</div><!--.entry-meta-->

		<?php if ( has_post_thumbnail() ) { ?>
			<div class="details-image">
				<?php the_post_thumbnail( 'full', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
			</div>
		<?php } ?>
		<div class="tab pull-left">
			<ul class="nav-tabs tp-tabs">
				<li class="tab-link active" data-tab="tab-3"><a href="#."><?php esc_html_e( 'Courses', 'corporate-education-pro' ); ?></a></li>
				<li class="tab-link" data-tab="tab-4"><a href="#."><?php esc_html_e( 'Curriculum', 'corporate-education-pro' ); ?></a></li>
				<li class="tab-link" data-tab="tab-5"><a href="#."><?php esc_html_e( 'Counselors', 'corporate-education-pro' ); ?></a></li>
				<li class="tab-link" data-tab="tab-6"><a href="#."><?php esc_html_e( 'Reviews', 'corporate-education-pro' ); ?></a></li>
			</ul><!--.tabs-->
		</div><!--.tab/pull-left-->

		<div class="courses-list two-columns">

			<div id="tab-3" class="tab-content active">
				<div class="tab-pane">
					<div class="details-text">
						<h2><?php esc_html_e( 'COURSE DESCRIPTION', 'corporate-education-pro' ); ?></h2>
						<?php 
						the_content( sprintf(
							/* translators: %s: Name of current post. */
							wp_kses( __( 'Continue reading %s <span class="meta-nav">&rarr;</span>', 'corporate-education-pro' ), array( 'span' => array( 'class' => array() ) ) ),
							the_title( '<span class="screen-reader-text">"', '"</span>', false )
						) );
						?>
					</div><!--.details-text-->
				</div><!--.row-->
			</div><!--.tab-3-->

			<div id="tab-4" class="tab-content">
				<div class="tab-pane">
					<div class="details-text">
						<h2><?php esc_html_e( 'RELATED COURSES', 'corporate-education-pro' ); ?></h2>
						<ul>
							<?php 
							$terms = wp_get_post_terms( get_the_ID(), 'tp-course-category', array( "fields" => "all" ) );
							foreach ( $terms as $term ) :
								$term_id[] = $term->term_id;
							endforeach;
							$args = array(
				                'post_type'         => $post_type,
				                'post__not_in'		=> array( get_the_id() ),
				                'tax_query'         => array(
				                    array(
				                        'taxonomy'  => 'tp-course-category',
				                        'field'     => 'id',
				                        'terms'     => $term_id
				                    )
				                )
				            );
				            $posts = get_posts( $args );
				            foreach ( $posts as $post )	: ?>
								<li><span><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( get_the_title() ); ?></a></span></li>
				            <?php endforeach; 
				            wp_reset_postdata(); ?>			
						</ul>
					</div><!--.details-text-->

				</div><!--.tab-pane-->
			</div><!--.tab-4-->

			<div id="tab-5" class="tab-content">
				<div class="tab-pane">
					<div class="details-text">
						<h2><?php esc_html_e( 'COUNSELORS DETAIL', 'corporate-education-pro' ); ?></h2>
						<ul class="comment-list">
							<?php  
							$tp_course_counselors = get_post_meta( get_the_id(), 'tp_course_counselors_value', true );
							$tp_course_counselors = ! empty( $tp_course_counselors ) ? $tp_course_counselors : '';
							if ( ! empty( $tp_course_counselors ) && $tp_course_counselors[0] !== 0 ) :
								$args = array(
									'post_type'	=> 'tp-team',
									'post__in'	=> $tp_course_counselors
								);
								$posts = get_posts( $args );
								foreach ( $posts as $post ) : ?>

								<li>
									
									<?php 
									if ( has_post_thumbnail( $post->ID ) )
										the_post_thumbnail( 'thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) );
									else 
	                                	echo '<img src="' . esc_url( get_template_directory_uri() .'/assets/uploads/no-featured-image-300x300.jpg' ) . '" alt="'. esc_attr( get_the_title() ) .'">';
									?>
									<span>
										<a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( get_the_title( $post->ID ) ); ?></a>
										<?php 
										if ( function_exists( 'tp_team_designation' ) ) :
											tp_team_designation(); 
										endif;
										?>
									</span>

									<span class="course-counselor-detail">
										<?php echo corporate_education_pro_trim_content( 25, $post  ); ?>
									</span>

								</li>

								<?php endforeach; 
						        wp_reset_postdata(); 
					        else : ?>
					        	<h5><?php esc_html_e( 'No Counselor Found !', 'corporate-education-pro' ); ?></h5>
					        <?php endif; ?>	
						</ul>
					</div><!--.details-text-->

				</div><!--.tab-pane-->
			</div><!--.tab-5-->

			<div id="tab-6" class="tab-content course-comment-tab">
				<div class="tab-pane">
					<div class="details-text">
						<?php  
						// If comments are open or we have at least one comment, load up the comment template.
						if ( comments_open() || get_comments_number() ) :
							comments_template();
						endif;
						?>
					</div><!--.details-text-->

				</div><!--.tab-pane-->
			</div><!--.tab-6-->

		</div><!--.courses-list-->


		<div class="course-features">
			<h5><?php esc_html_e( 'COURSE FEATURE', 'corporate-education-pro' ); ?></h5>
			<ul>
				<?php if ( class_exists( 'TP_Education' ) ) : ?>
					<li><?php tp_course_price(); ?></li>
					<li><?php tp_course_type(); ?></li>
					<li><?php tp_course_students(); ?></li>
					<li><?php tp_course_duration(); ?></li>
					<li><?php tp_course_skills(); ?></li>
					<li><?php tp_course_language(); ?></li>
					<li><?php tp_course_assessment(); ?></li>
				<?php endif; ?>
			</ul>
		</div><!--.course-features-->

		<?php 
			wp_link_pages( array(
				'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'corporate-education-pro' ),
				'after'  => '</div>',
			) );

		?>

	</div><!-- .entry-content -->

	<?php  
	/**
	* Hook corporate_education_pro_action_post_pagination
	*  
	* @hooked corporate_education_pro_post_pagination 
	*/
	do_action( 'corporate_education_pro_action_post_pagination' );

	$courses = wp_count_posts( 'tp-course' );
	$courses = $courses->publish;

	if ( $courses > 1 ) :

		$args = array(
			'post_type'			=> 'tp-course',
			'posts_per_page'	=> 2,
			'order'				=> 'rand',
			'post__not_in'		=> array( get_the_ID() )
			);
		$posts = get_posts( $args );
		if ( ! empty( $posts ) ) :
		?>
			<div id="featured-courses" class="related-courses">
				<header class="entry-header">
	                <h2><?php esc_html_e( 'YOU MAY LIKE', 'corporate-education-pro' ); ?></h2>
	            </header>
				
				<div class="entry-content col-2">
					<?php foreach ( $posts as $post ) : ?>
						<div class="hentry">
	                        <div class="featured-course-wrapper">
	                            <figure class="featured-image">
	                                <div class="white-shape top"></div>
	                                <div class="white-shape top right"></div>
	                                <div class="white-shape bottom"></div>
	                                <div class="white-shape bottom left"></div>

	                                <a href="<?php the_permalink( $post->ID ); ?>">
	                                <?php if( has_post_thumbnail( $post->ID ) ) :
										the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) );
									else :
						                echo '<img src="' . esc_url( get_template_directory_uri().'/assets/uploads/no-featured-image-400x270.jpg' ) . '" alt="' . esc_attr( get_the_title( $post->ID ) ) . '">';
									endif; ?>
	                                </a>
	                                <?php if ( function_exists( 'tp_course_price' ) ) :
	                                	tp_course_price();
	                                endif; ?>
	                            </figure>
	                            <div class="entry-container">
	                                <h5 class="featured-title"><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( get_the_title( $post->ID ) ); ?></a></h5>
	                                <p><?php echo corporate_education_pro_trim_content( 20, $post ); ?></p>
	                            </div><!-- .entry-container -->
	                        </div><!-- .featured-course-wrapper -->
	                    </div><!-- .hentry -->
					<?php endforeach; 
					wp_reset_postdata(); ?>
				</div><!--.related-courses-->
			</div><!--.related-courses-->  

		<?php endif; 
	endif; ?>
</article><!-- #post-## -->
